==========================
Package Sync Compatibility
==========================

Package sync is regularly tested against the following package managers:

.. list-table:: Package Managers
   :widths: 25 25
   :header-rows: 1

   * - Package Manager
     - Status
   * - mamba
     - Y
   * - micromamba
     - Y
   * - conda
     - Y
   * - apt
     - Y
   * - yum
     - Y
   * - venv
     - Y
   * - poetry
     - Y
   * - pdm
     - ?

On the following operating systems (note that not every package manager is tested on every OS):

.. list-table:: OS
   :widths: 25 25 25
   :header-rows: 1

   * - OS
     - Version
     - Status
   * - debian
     - bullseye
     - Y
   * - debian
     - buster
     - Y
   * - ubuntu
     - 22.04
     - Y
   * - ubuntu
     - 20.04
     - Y
   * - amazonlinux
     - 2
     - Y
   * - macOS
     - 12
     - Y
   * - macOS
     - 11
     - Y
   * - macOS
     - 10.15
     - Y
   * - Windows Server
     - 2022
     - Y
   * - Windows Server
     - 2019
     - Y

Note that it's still possible to encounter errors, even using package managers and OSs listed here. If you run into issues, please `open an issue <https://github.com/coiled/feedback/issues/new/choose>`_ or email support@coiled.io.